#  Copyright (C) 2024
#  ABM, Moscow
#
#  UNPUBLISHED PROPRIETARY MATERIAL.
#  ALL RIGHTS RESERVED.
#
#  Authors: Revva Konstantin <k.revva@abm-jsc.ru>

from dataclasses import dataclass

from detector_connector import DetectorSettings


@dataclass(kw_only=True, frozen=True)
class ShiftSettings(DetectorSettings):
    similarity_threshold: float
